@@ -518,3 +518,42 @@ Export_adegenet_genind <- function(object, ploidyIndex = 1){
 
   return(out)
 }
+
+Export_polymapR_probs <- function(object, maxPcutoff = 0.9,
+                                  correctParentalGenos = TRUE,
+                                  multiallelic = "correct"){
+  if(!is(object, "RADdata")){
+    stop("RADdata object needed")
+  }
+  if(length(object$posteriorProb) > 1){
+    stop("Only one ploidy allowed for Export_polymapR_probs.")
+  }
+  object <- RemoveUngenotypedLoci(object, removeNonvariant = TRUE)
+  p1 <- dim(object$posteriorProb[[1]])[1] # ploidy plus one
+  omitals <- OneAllelePerMarker(object, commonAllele = TRUE)
+  keepals <- GetAlleleNames(object)[-omitals]
+  
+  probmat <- matrix(object$posteriorProb[[1]][,,keepals],
+                    nrow = nTaxa(object) * length(keepals),
+                    ncol = p1,
+                    dimnames = list(NULL, paste0("P", seq_len(p1) - 1L)),
+                    byrow = TRUE)
+  out <- data.frame(SampleName = rep(GetTaxa(object), times = length(keepals)),
+                    MarkerName = rep(keepals, each = nTaxa(object)),
+                    probmat)
+  genomat <- GetProbableGenotypes(object, omit1allelePerLocus = TRUE,
+                                  omitCommonAllele = TRUE,
+                                  correctParentalGenos = correctParentalGenos,
+                                  multiallelic = multiallelic)$genotypes
+  genovect <- as.vector(genomat)
+  out$maxP <- numeric(nTaxa(object) * length(keepals))
+  for(i in seq_len(p1) - 1L){
+    theserows <- which(genovect == i)
+    out$maxP[theserows] <- out[[paste0("P", i)]][theserows]
+  }
+  out$maxgeno <- genovect
+  out$geno <- genovect
+  out$geno[out$maxP < maxPcutoff] <- NA_real_
+  
+  return(out)
+}
